==> helm-annotations-4.0.1-sources.jar: io/dekorate/helm/config/AddIfStatementFluent.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddIfStatementFluent<A extends AddIfStatementFluent<A>> extends BaseFluent<A>{
  public AddIfStatementFluent() {
  }
  public AddIfStatementFluent(AddIfStatement instance) {
    instance = (instance != null ? instance : new AddIfStatement());

    if (instance != null) {
      this.withProperty(instance.getProperty());
      this.withOnResourceKind(instance.getOnResourceKind());
      this.withOnResourceName(instance.getOnResourceName());
      this.withWithDefaultValue(instance.getWithDefaultValue());
      this.withDescription(instance.getDescription());
    }
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  public String getProperty() {
    return this.property;
  }
  public A withProperty(String property) {
    this.property=property; return (A) this;
  }
  public boolean hasProperty() {
    return this.property != null;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public A withOnResourceKind(String onResourceKind) {
    this.onResourceKind=onResourceKind; return (A) this;
  }
  public boolean hasOnResourceKind() {
    return this.onResourceKind != null;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public A withOnResourceName(String onResourceName) {
    this.onResourceName=onResourceName; return (A) this;
  }
  public boolean hasOnResourceName() {
    return this.onResourceName != null;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public A withWithDefaultValue(Boolean withDefaultValue) {
    this.withDefaultValue=withDefaultValue; return (A) this;
  }
  public boolean hasWithDefaultValue() {
    return this.withDefaultValue != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public boolean hasDescription() {
    return this.description != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddIfStatementFluent that = (AddIfStatementFluent) o;
    if (!java.util.Objects.equals(property, that.property)) return false;

    if (!java.util.Objects.equals(onResourceKind, that.onResourceKind)) return false;

    if (!java.util.Objects.equals(onResourceName, that.onResourceName)) return false;

    if (!java.util.Objects.equals(withDefaultValue, that.withDefaultValue)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (property != null) { sb.append("property:"); sb.append(property + ","); }
    if (onResourceKind != null) { sb.append("onResourceKind:"); sb.append(onResourceKind + ","); }
    if (onResourceName != null) { sb.append("onResourceName:"); sb.append(onResourceName + ","); }
    if (withDefaultValue != null) { sb.append("withDefaultValue:"); sb.append(withDefaultValue + ","); }
    if (description != null) { sb.append("description:"); sb.append(description); }
    sb.append("}");
    return sb.toString();
  }
  public A withWithDefaultValue() {
    return withWithDefaultValue(true);
  }
  
}

==> helm-annotations-4.1.0-sources.jar: io/dekorate/helm/config/AddIfStatementFluent.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AddIfStatementFluent<A extends AddIfStatementFluent<A>> extends BaseFluent<A>{
  public AddIfStatementFluent() {
  }
  
  public AddIfStatementFluent(AddIfStatement instance) {
    this.copyInstance(instance);
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  
  protected void copyInstance(AddIfStatement instance) {
    instance = (instance != null ? instance : new AddIfStatement());
    if (instance != null) {
          this.withProperty(instance.getProperty());
          this.withOnResourceKind(instance.getOnResourceKind());
          this.withOnResourceName(instance.getOnResourceName());
          this.withWithDefaultValue(instance.getWithDefaultValue());
          this.withDescription(instance.getDescription());
        }
  }
  
  public String getProperty() {
    return this.property;
  }
  
  public A withProperty(String property) {
    this.property = property;
    return (A) this;
  }
  
  public boolean hasProperty() {
    return this.property != null;
  }
  
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  
  public A withOnResourceKind(String onResourceKind) {
    this.onResourceKind = onResourceKind;
    return (A) this;
  }
  
  public boolean hasOnResourceKind() {
    return this.onResourceKind != null;
  }
  
  public String getOnResourceName() {
    return this.onResourceName;
  }
  
  public A withOnResourceName(String onResourceName) {
    this.onResourceName = onResourceName;
    return (A) this;
  }
  
  public boolean hasOnResourceName() {
    return this.onResourceName != null;
  }
  
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  
  public A withWithDefaultValue(Boolean withDefaultValue) {
    this.withDefaultValue = withDefaultValue;
    return (A) this;
  }
  
  public boolean hasWithDefaultValue() {
    return this.withDefaultValue != null;
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description = description;
    return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddIfStatementFluent that = (AddIfStatementFluent) o;
    if (!java.util.Objects.equals(property, that.property)) return false;
    if (!java.util.Objects.equals(onResourceKind, that.onResourceKind)) return false;
    if (!java.util.Objects.equals(onResourceName, that.onResourceName)) return false;
    if (!java.util.Objects.equals(withDefaultValue, that.withDefaultValue)) return false;
    if (!java.util.Objects.equals(description, that.description)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (property != null) { sb.append("property:"); sb.append(property + ","); }
    if (onResourceKind != null) { sb.append("onResourceKind:"); sb.append(onResourceKind + ","); }
    if (onResourceName != null) { sb.append("onResourceName:"); sb.append(onResourceName + ","); }
    if (withDefaultValue != null) { sb.append("withDefaultValue:"); sb.append(withDefaultValue + ","); }
    if (description != null) { sb.append("description:"); sb.append(description); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withWithDefaultValue() {
    return withWithDefaultValue(true);
  }
  

}
